@@ -57,8 +57,6 @@ use super::{full_integration_dump, integration_dump};
 use crate::conductor::p2p_agent_store::get_single_agent_info;
 use crate::conductor::p2p_agent_store::query_peer_density;
 use crate::conductor::p2p_agent_store::P2pBatch;
-use crate::conductor::p2p_metrics::put_metric_datum;
-use crate::conductor::p2p_metrics::query_metrics;
 use crate::core::queue_consumer::QueueConsumerMap;
 use crate::core::ribosome::guest_callback::post_commit::PostCommitArgs;
 use crate::core::ribosome::real_ribosome::RealRibosome;
@@ -303,6 +301,9 @@ pub trait ConductorHandleT: Send + Sync {
         dht_ops_cursor: Option<u64>,
     ) -> ConductorApiResult<FullStateDump>;
 
+    /// Dump the network metrics
+    async fn dump_network_metrics(&self, dna_hash: Option<DnaHash>) -> ConductorApiResult<String>;
+
     /// Access the broadcast Sender which will send a Signal across every
     /// attached app interface
     async fn signal_broadcaster(&self) -> SignalBroadcaster;
@@ -612,6 +613,24 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
                     .boxed()
                     .into()));
                 }
+                KGenReq::RecordMetrics { space, records } => {
+                    let env = { self.p2p_metrics_env(space) };
+                    respond.respond(Ok(async move {
+                        use holochain_sqlite::db::AsP2pMetricStoreConExt;
+                        let permit = env.conn_permit().await;
+                        let res = tokio::task::spawn_blocking(move || {
+                            let mut conn = env.from_permit(permit)?;
+                            conn.p2p_log_metrics(records)
+                        })
+                        .await;
+                        let res = res
+                            .map_err(holochain_p2p::HolochainP2pError::other)
+                            .and_then(|r| r.map_err(holochain_p2p::HolochainP2pError::other))?;
+                        Ok(KGenRes::RecordMetrics(res))
+                    }
+                    .boxed()
+                    .into()));
+                }
             },
             PutAgentInfoSigned {
                 peer_data, respond, ..
@@ -711,26 +730,6 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
                     .map_err(holochain_p2p::HolochainP2pError::other);
                 respond.respond(Ok(async move { res }.boxed().into()));
             }
-            PutMetricDatum {
-                respond,
-                agent,
-                metric,
-                timestamp,
-                ..
-            } => {
-                let env = { self.p2p_metrics_env(space) };
-                let res = put_metric_datum(env, agent, metric, timestamp)
-                    .await
-                    .map_err(holochain_p2p::HolochainP2pError::other);
-                respond.respond(Ok(async move { res }.boxed().into()));
-            }
-            QueryMetrics { respond, query, .. } => {
-                let env = { self.p2p_metrics_env(space) };
-                let res = query_metrics(env, query)
-                    .await
-                    .map_err(holochain_p2p::HolochainP2pError::other);
-                respond.respond(Ok(async move { res }.boxed().into()));
-            }
             SignNetworkData {
                 respond,
                 to_agent,
@@ -1194,6 +1193,14 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
         Ok(out)
     }
 
+    async fn dump_network_metrics(&self, dna_hash: Option<DnaHash>) -> ConductorApiResult<String> {
+        use holochain_p2p::HolochainP2pSender;
+        self.holochain_p2p
+            .dump_network_metrics(dna_hash)
+            .await
+            .map_err(super::api::error::ConductorApiError::other)
+    }
+
     async fn signal_broadcaster(&self) -> SignalBroadcaster {
         self.conductor.signal_broadcaster()
     }
