@@ -56,7 +56,11 @@ pub fn delete<'a>(
                 Ok(header_hash)
             })
         }
-        _ => unreachable!(),
+        _ => Err(WasmError::Host(RibosomeError::HostFnPermissions(
+            call_context.zome.zome_name().clone(),
+            call_context.function_name().clone(),
+            "delete".into()
+        ).to_string()))
     }
 }
 
