@@ -7,6 +7,7 @@ use holochain_types::prelude::*;
 use holochain_wasmer_host::prelude::WasmError;
 use std::sync::Arc;
 use holochain_zome_types::GetOptions;
+use crate::core::ribosome::RibosomeError;
 
 #[allow(clippy::extra_unused_lifetimes)]
 pub fn must_get_valid_element<'a>(
@@ -74,7 +75,11 @@ pub fn must_get_valid_element<'a>(
                     }
             })
         },
-        _ => unreachable!(),
+        _ => Err(WasmError::Host(RibosomeError::HostFnPermissions(
+            call_context.zome.zome_name().clone(),
+            call_context.function_name().clone(),
+            "must_get_valid_element".into()
+        ).to_string()))
     }
 
 }
\ No newline at end of file
