@@ -5,6 +5,7 @@ use holochain_types::access::Permission;
 use holochain_wasmer_host::prelude::WasmError;
 use holochain_zome_types::Timestamp;
 use std::sync::Arc;
+use crate::core::ribosome::RibosomeError;
 
 pub fn sys_time(
     _ribosome: Arc<impl RibosomeT>,
@@ -16,7 +17,11 @@ pub fn sys_time(
             non_determinism: Permission::Allow,
             ..
         } => Ok(holochain_zome_types::Timestamp::now()),
-        _ => unreachable!(),
+        _ => Err(WasmError::Host(RibosomeError::HostFnPermissions(
+            call_context.zome.zome_name().clone(),
+            call_context.function_name().clone(),
+            "sys_time".into()
+        ).to_string()))
     }
 }
 
