@@ -143,7 +143,7 @@ async fn app_validation_workflow_inner(
         );
         let (t, a, r) = workspace
             .dht_env
-            .async_commit(move |mut txn| {
+            .async_commit(move |txn| {
                 let mut total = 0;
                 let mut awaiting = 0;
                 let mut rejected = 0;
@@ -162,23 +162,23 @@ async fn app_validation_workflow_inner(
                         Outcome::Accepted => {
                             total += 1;
                             if let Dependency::Null = dependency {
-                                put_integrated(&mut txn, op_hash, ValidationStatus::Valid)?;
+                                put_integrated(txn, op_hash, ValidationStatus::Valid)?;
                             } else {
-                                put_integration_limbo(&mut txn, op_hash, ValidationStatus::Valid)?;
+                                put_integration_limbo(txn, op_hash, ValidationStatus::Valid)?;
                             }
                         }
                         Outcome::AwaitingDeps(deps) => {
                             awaiting += 1;
                             let status = ValidationLimboStatus::AwaitingAppDeps(deps);
-                            put_validation_limbo(&mut txn, op_hash, status)?;
+                            put_validation_limbo(txn, op_hash, status)?;
                         }
                         Outcome::Rejected(_) => {
                             rejected += 1;
                             tracing::warn!("Received invalid op! Warrants aren't implemented yet, so we can't do anything about this right now, but be warned that somebody on the network has maliciously hacked their node.\nOp: {:?}", op_light);
                             if let Dependency::Null = dependency {
-                                put_integrated(&mut txn, op_hash, ValidationStatus::Rejected)?;
+                                put_integrated(txn, op_hash, ValidationStatus::Rejected)?;
                             } else {
-                                put_integration_limbo(&mut txn, op_hash, ValidationStatus::Rejected)?;
+                                put_integration_limbo(txn, op_hash, ValidationStatus::Rejected)?;
                             }
                         }
                     }
